@@ -33,8 +33,7 @@
 #include <stdio.h>
 #include <string.h>
 #include <gudev/gudev.h>
-
-#include <linux/input-event-codes.h>
+#include <libevdev/libevdev.h>
 
 #if !HAVE_G_MEMDUP2
 #define g_memdup2 g_memdup
@@ -380,6 +379,10 @@ libwacom_copy(const WacomDevice *device)
 		WacomButton *b = g_memdup2(a, sizeof(WacomButton));
 		g_hash_table_insert(d->buttons, k, b);
 	}
+
+	d->num_keycodes = device->num_keycodes;
+	memcpy(d->keycodes, device->keycodes, sizeof(device->keycodes));
+
 	return d;
 }
 
@@ -492,7 +495,8 @@ libwacom_compare(const WacomDevice *a, const WacomDevice *b, WacomCompareFlags f
 	if (a->status_leds->len != b->status_leds->len)
 		return 1;
 
-	if (memcmp(a->status_leds->data, b->status_leds->data,
+	if (a->status_leds->len > 0 &&
+	    memcmp(a->status_leds->data, b->status_leds->data,
 		   sizeof(WacomStatusLEDs) * a->status_leds->len) != 0)
 		return 1;
 
@@ -754,9 +758,14 @@ static void print_button_evdev_codes(int fd, const WacomDevice *device)
 	unsigned idx = 0;
 
 	for (b = 'A'; b < 'A' + nbuttons; b++) {
+		unsigned int code = libwacom_get_button_evdev_code(device, b);
+		const char *str = libevdev_event_code_get_name(EV_KEY, code);
+
 		assert(idx < sizeof(buf) - 30);
-		idx += snprintf(buf + idx, 30, "0x%x;",
-				libwacom_get_button_evdev_code(device, b));
+		if (str)
+			idx += snprintf(buf + idx, 30, "%s;", str);
+		else
+			idx += snprintf(buf + idx, 30, "0x%x;", code);
 	}
 	dprintf(fd, "EvdevCodes=%s\n", buf);
 }
@@ -882,7 +891,6 @@ libwacom_print_device_description(int fd, const WacomDevice *device)
 	print_supported_leds(fd, device);
 
 	dprintf(fd, "NumStrips=%d\n",	libwacom_get_num_strips(device));
-	dprintf(fd, "Buttons=%d\n",		libwacom_get_num_buttons(device));
 	dprintf(fd, "\n");
 
 	print_buttons_for_device(fd, device);
@@ -1117,6 +1125,12 @@ libwacom_get_num_buttons(const WacomDevice *device)
 	return g_hash_table_size(device->buttons);
 }
 
+LIBWACOM_EXPORT int
+libwacom_get_num_keys(const WacomDevice *device)
+{
+	return device->num_keycodes;
+}
+
 LIBWACOM_EXPORT const int *
 libwacom_get_supported_styli(const WacomDevice *device, int *num_styli)
 {
@@ -1350,7 +1364,6 @@ libwacom_print_stylus_description (int fd, const WacomStylus *stylus)
 
 	dprintf(fd, "[%#x]\n",		libwacom_stylus_get_id(stylus));
 	dprintf(fd, "Name=%s\n",	libwacom_stylus_get_name(stylus));
-	dprintf(fd, "Buttons=%d\n",	libwacom_stylus_get_num_buttons(stylus));
 	dprintf(fd, "PairedIds=");
 	paired_ids = libwacom_stylus_get_paired_ids(stylus, &count);
 	for (i = 0; i < count; i++) {
