@@ -24,9 +24,7 @@
  *	Peter Hutterer (peter.hutterer@redhat.com)
  */
 
-#ifdef HAVE_CONFIG_H
 #include "config.h"
-#endif
 
 #include <linux/input-event-codes.h>
 #include <glib.h>
@@ -228,6 +226,16 @@ test_cintiq13hd(struct fixture *f, gconstpointer user_data)
 	libwacom_destroy(device);
 }
 
+static void
+test_cintiqpro13(struct fixture *f, gconstpointer user_data)
+{
+	WacomDevice *device = libwacom_new_from_name(f->db, "Wacom Cintiq Pro 13", NULL);
+	g_assert_nonnull(device);
+	g_assert_cmpint(libwacom_get_num_keys(device), ==, 5);
+
+	libwacom_destroy(device);
+}
+
 static void
 test_bamboopen(struct fixture *f, gconstpointer user_data)
 {
@@ -238,6 +246,19 @@ test_bamboopen(struct fixture *f, gconstpointer user_data)
 	g_assert_cmpint(libwacom_get_button_evdev_code(device, 'C'), ==, BTN_LEFT);
 	g_assert_cmpint(libwacom_get_button_evdev_code(device, 'D'), ==, BTN_RIGHT);
 	g_assert_cmpstr(libwacom_get_model_name(device), ==, "MTE-450");
+
+	libwacom_destroy(device);
+}
+
+static void
+test_dellcanvas(struct fixture *f, gconstpointer user_data)
+{
+	WacomDevice *device = libwacom_new_from_name(f->db, "Dell Canvas 27", NULL);
+
+	g_assert_nonnull(device);
+	g_assert_true(libwacom_get_integration_flags(device) & WACOM_DEVICE_INTEGRATED_DISPLAY);
+	g_assert_false(libwacom_get_integration_flags(device) & WACOM_DEVICE_INTEGRATED_SYSTEM);
+
 	libwacom_destroy(device);
 }
 
@@ -283,9 +304,15 @@ int main(int argc, char **argv)
 	g_test_add("/load/056a:0304", struct fixture, NULL,
 		   fixture_setup, test_cintiq13hd,
 		   fixture_teardown);
+	g_test_add("/load/056a:034f", struct fixture, NULL,
+		   fixture_setup, test_cintiqpro13,
+		   fixture_teardown);
 	g_test_add("/load/056a:0065", struct fixture, NULL,
 		   fixture_setup, test_bamboopen,
 		   fixture_teardown);
+	g_test_add("/load/056a:4200", struct fixture, NULL,
+		   fixture_setup, test_dellcanvas,
+		   fixture_teardown);
 	g_test_add("/load/056a:WACf004", struct fixture, NULL,
 		   fixture_setup, test_wacf004,
 		   fixture_teardown);
